MethodChannelFlutterMediaSession class
An implementation of FlutterMediaSessionPlatform that uses method channels.
- Inheritance
-
- Object
- PlatformInterface
- FlutterMediaSessionPlatform
- MethodChannelFlutterMediaSession
Constructors
Properties
- eventChannel → EventChannel
-
The event channel used to receive media actions from the native platform.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- methodChannel → MethodChannel
-
The method channel used to interact with the native platform.
final
-
onMediaAction
→ Stream<
MediaAction> -
A stream of media actions emitted by the current platform.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
activate(
) → Future< void> -
Activates the media session on the current platform.
override
-
deactivate(
) → Future< void> -
Deactivates the media session on the current platform.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
updateMetadata(
MediaMetadata metadata) → Future< void> -
Updates the media metadata on the current platform.
override
-
updatePlaybackState(
PlaybackState state) → Future< void> -
Updates the playback state on the current platform.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited