eventChannel property
The event channel used to receive media actions from the native platform.
Implementation
final eventChannel = const EventChannel('flutter_media_session_events');
The event channel used to receive media actions from the native platform.
final eventChannel = const EventChannel('flutter_media_session_events');