FlutterMediaSessionPlatform class abstract

The platform-specific interface for FlutterMediaSession.

Platform implementations should extend this class and register themselves with FlutterMediaSessionPlatform.instance.

Inheritance
  • Object
  • PlatformInterface
  • FlutterMediaSessionPlatform
Implementers

Properties

hashCode int
The hash code for this object.
no setterinherited
onMediaAction Stream<MediaAction>
A stream of media actions emitted by the current platform.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

activate() Future<void>
Activates the media session on the current platform.
deactivate() Future<void>
Deactivates the media session on the current platform.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
updateMetadata(MediaMetadata metadata) Future<void>
Updates the media metadata on the current platform.
updatePlaybackState(PlaybackState state) Future<void>
Updates the playback state on the current platform.

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

instance FlutterMediaSessionPlatform
The default instance of FlutterMediaSessionPlatform to use.
getter/setter pair