onMediaAction property
A stream of media actions emitted by the current platform.
Implementation
@override
Stream<MediaAction> get onMediaAction => _actionController.stream;
A stream of media actions emitted by the current platform.
@override
Stream<MediaAction> get onMediaAction => _actionController.stream;